genshi.template

Package genshi :: Package template |

# Package template

Implementation of the template engine.

Submodules
genshi.template._ast24 genshi.template.ast24: Emulation of the proper abstract syntax tree API for Python 2.4. genshi.template.astutil: Support classes for generating code from abstract syntax trees. genshi.template.base: Basic templating functionality. genshi.template.directives: Implementation of the various template directives. genshi.template.eval: Support for "safe" evaluation of Python expressions. genshi.template.interpolation: String interpolation routines, i.e. genshi.template.loader: Template loading and caching. genshi.template.markup: Markup templating engine. genshi.template.plugin: Basic support for the template engine plugin API used by TurboGears and CherryPy/Buffet. genshi.template.text: Plain text templating engine.

Variables
| __package__ = ``'``genshi.template``'``